Method: AWS::DynamoDB::Client#batch_write_item

Defined in:
lib/aws/dynamo_db/client.rb

#batch_write_item(options = {}) ⇒ Core::Response

Calls the BatchWriteItem API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :request_items - required - (Hash<String,Array<Hash>>) A map of table name to list-of-write-requests. Used as input to the BatchWriteItem API call

      • :put_request - (Hash)

        • :item - required - (Hash<String,Hash>) The item to put

          • :s - (String) Strings are Unicode with UTF-8 binary encoding. The maximum size is limited by the size of the primary key (1024 bytes as a range part of a key or 2048 bytes as a single part hash key) or the item size (64k).

          • :n - (String) Numbers are positive or negative exact-value decimals and integers. A number can have up to 38 digits precision and can be between 10^-128 to 10^+126.

          • :b - (String) Binary attributes are sequences of unsigned bytes.

          • :ss - (Array<String>) A set of strings.

          • :ns - (Array<String>) A set of numbers.

          • :bs - (Array<String>) A set of binary attributes.

      • :delete_request - (Hash)

        • :key - required - (Hash) The item’s key to be delete

          • :hash_key_element - required - (Hash) A hash key element is treated as the primary key, and can be a string or a number. Single attribute primary keys have one index value. The value can be String, Number, StringSet, NumberSet.

            • :s - (String) Strings are Unicode with UTF-8 binary encoding. The maximum size is limited by the size of the primary key (1024 bytes as a range part of a key or 2048 bytes as a single part hash key) or the item size (64k).

            • :n - (String) Numbers are positive or negative exact-value decimals and integers. A number can have up to 38 digits precision and can be between 10^-128 to 10^+126.

            • :b - (String) Binary attributes are sequences of unsigned bytes.

            • :ss - (Array<String>) A set of strings.

            • :ns - (Array<String>) A set of numbers.

            • :bs - (Array<String>) A set of binary attributes.

          • :range_key_element - (Hash) A range key element is treated as a secondary key (used in conjunction with the primary key), and can be a string or a number, and is only used for hash-and-range primary keys. The value can be String, Number, StringSet, NumberSet.

            • :s - (String) Strings are Unicode with UTF-8 binary encoding. The maximum size is limited by the size of the primary key (1024 bytes as a range part of a key or 2048 bytes as a single part hash key) or the item size (64k).

            • :n - (String) Numbers are positive or negative exact-value decimals and integers. A number can have up to 38 digits precision and can be between 10^-128 to 10^+126.

            • :b - (String) Binary attributes are sequences of unsigned bytes.

            • :ss - (Array<String>) A set of strings.

            • :ns - (Array<String>) A set of numbers.

            • :bs - (Array<String>) A set of binary attributes.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • Responses - (Hash<String,Hash>)

      • ConsumedCapacityUnits - (Numeric)

    • UnprocessedItems - (Hash<String,Hash>)

      • value - (Array<Hash>)

        • PutRequest - (Hash)

          • Item - (Hash<String,Hash>)

            • S - (String)

            • N - (String)

            • B - (String)

            • SS - (Array<String>)

            • NS - (Array<String>)

            • BS - (Array<Blob>)

        • DeleteRequest - (Hash)

          • Key - (Hash)

            • HashKeyElement - (Hash)

              • S - (String)

              • N - (String)

              • B - (String)

              • SS - (Array<String>)

              • NS - (Array<String>)

              • BS - (Array<Blob>)

            • RangeKeyElement - (Hash)

              • S - (String)

              • N - (String)

              • B - (String)

              • SS - (Array<String>)

              • NS - (Array<String>)

              • BS - (Array<Blob>)



# File 'lib/aws/dynamo_db/client.rb', line 101