Method: AWS::ElasticBeanstalk::Client#describe_environments

Defined in:
lib/aws/elastic_beanstalk/client.rb

#describe_environments(options = {}) ⇒ Core::Response

Calls the DescribeEnvironments API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :application_name - (String) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.

    • :version_label - (String) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.

    • :environment_ids - (Array<String>) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.

    • :environment_names - (Array<String>) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.

    • :include_deleted - (Boolean) Indicates whether to include deleted environments: true : Environments that have been deleted after IncludedDeletedBackTo are displayed. false : Do not include deleted environments.

    • :included_deleted_back_to - (String<ISO8601 datetime>) If specified when IncludeDeleted is set to true , then environments deleted after this date are displayed.

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • :environments - (Array<Hash>)

      • :environment_name - (String)

      • :environment_id - (String)

      • :application_name - (String)

      • :version_label - (String)

      • :solution_stack_name - (String)

      • :template_name - (String)

      • :description - (String)

      • :endpoint_url - (String)

      • :cname - (String)

      • :date_created - (Time)

      • :date_updated - (Time)

      • :status - (String)

      • :health - (String)

      • :resources - (Hash)

        • :load_balancer - (Hash)

          • :load_balancer_name - (String)

          • :domain - (String)

          • :listeners - (Array<Hash>)

            • :protocol - (String)

            • :port - (Integer)



# File 'lib/aws/elastic_beanstalk/client.rb', line 437