Module: AWS::Core::ServiceInterface

Instance Method Summary collapse

Instance Method Details

#initialize(options = {}) ⇒ Object

Returns a new interface object for this service. You can override any of the global configuration parameters by passing them in as hash options. They are merged with AWS.config or merged with the provided :config object.

@ec2 = AWS::EC2.new(:max_retries => 2)

Options Hash (options):

  • :config (Configuration)

    An AWS::Configuration object to initialize this service interface object with. Defaults to AWS.config when not provided.

See Also:

  • AWS::Cofiguration


47
48
49
50
51
52
# File 'lib/aws/core/service_interface.rb', line 47

def initialize options = {}
  options = options.dup
  @config = (options.delete(:config) || AWS.config)
  @config = @config.with(options)
  @client = @config.send(Inflection.ruby_name(self.class.name.split('::').last) + '_client')
end

#inspectString



55
56
57
# File 'lib/aws/core/service_interface.rb', line 55

def inspect
  "<#{self.class}>"
end