Module: AWS::S3::Errors

Extended by:
Core::LazyErrorClasses
Defined in:
lib/aws/s3/errors.rb

Overview

This module contains exception classes for each of the error types that S3 can return. You can use these classes to rescue specific errors, for example:

begin S3.new.buckets.mybucket. objects.myobj.write("HELLO") rescue S3::Errors::NoSuchBucket => e S3.new.buckets.create("mybucket") retry end

All errors raised as a result of error responses from the service are instances of either ClientError or ServerError.

Defined Under Namespace

Classes: BatchDeleteError, IncorrectClientSideEncryptionKey, NoSuchKey, NotModified

Constant Summary

Constants included from Core::LazyErrorClasses

Core::LazyErrorClasses::BASE_ERROR_GRAMMAR

Method Summary

Methods included from Core::LazyErrorClasses

const_missing, error_class