Class: AWS::StorageGateway::Client

Inherits:
Core::JSONClient show all
Defined in:
lib/aws/storage_gateway/client.rb

Overview

Client class for AWS Storage Gateway.

Instance Attribute Summary

Attributes inherited from Core::Client

#config, #http_read_timeout

Instance Method Summary collapse

Methods inherited from Core::Client

#initialize, #log_warning, #operations, operations, #with_http_handler, #with_options

Constructor Details

This class inherits a constructor from AWS::Core::Client

Instance Method Details

#activate_gateway(options = {}) ⇒ Core::Response

Calls the ActivateGateway API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :activation_key - required - (String)
    • :gateway_name - required - (String)
    • :gateway_timezone - required - (String)
    • :gateway_region - required - (String)
    • :gateway_type - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 25


#add_cache(options = {}) ⇒ Core::Response

Calls the AddCache API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :disk_ids - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 38


#add_upload_buffer(options = {}) ⇒ Core::Response

Calls the AddUploadBuffer API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :disk_ids - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 48


#add_working_storage(options = {}) ⇒ Core::Response

Calls the AddWorkingStorage API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :disk_ids - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 58


#create_cachedi_scsi_volume(options = {}) ⇒ Core::Response

Calls the CreateCachediSCSIVolume API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :volume_size_in_bytes - required - (Integer)
    • :snapshot_id - (String)
    • :target_name - required - (String)
    • :network_interface_id - required - (String)
    • :client_token - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)
    • TargetARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 68


#create_snapshot(options = {}) ⇒ Core::Response

Calls the CreateSnapshot API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)
    • :snapshot_description - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)
    • SnapshotId - (String)


# File 'lib/aws/storage_gateway/client.rb', line 83


#create_snapshot_from_volume_recovery_point(options = {}) ⇒ Core::Response

Calls the CreateSnapshotFromVolumeRecoveryPoint API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)
    • :snapshot_description - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • SnapshotId - (String)
    • VolumeARN - (String)
    • VolumeRecoveryPointTime - (String)


# File 'lib/aws/storage_gateway/client.rb', line 94


#create_storedi_scsi_volume(options = {}) ⇒ Core::Response

Calls the CreateStorediSCSIVolume API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :disk_id - required - (String)
    • :snapshot_id - (String)
    • :preserve_existing_data - required - (Boolean)
    • :target_name - required - (String)
    • :network_interface_id - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)
    • VolumeSizeInBytes - (Integer)
    • TargetARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 106


#delete_bandwidth_rate_limit(options = {}) ⇒ Core::Response

Calls the DeleteBandwidthRateLimit API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :bandwidth_type - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 122


#delete_chap_credentials(options = {}) ⇒ Core::Response

Calls the DeleteChapCredentials API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :target_arn - required - (String)
    • :initiator_name - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • TargetARN - (String)
    • InitiatorName - (String)


# File 'lib/aws/storage_gateway/client.rb', line 132


#delete_gateway(options = {}) ⇒ Core::Response

Calls the DeleteGateway API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 143


#delete_snapshot_schedule(options = {}) ⇒ Core::Response

Calls the DeleteSnapshotSchedule API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 152


#delete_volume(options = {}) ⇒ Core::Response

Calls the DeleteVolume API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 161


#describe_bandwidth_rate_limit(options = {}) ⇒ Core::Response

Calls the DescribeBandwidthRateLimit API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • AverageUploadRateLimitInBitsPerSec - (Integer)
    • AverageDownloadRateLimitInBitsPerSec - (Integer)


# File 'lib/aws/storage_gateway/client.rb', line 170


#describe_cache(options = {}) ⇒ Core::Response

Calls the DescribeCache API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • DiskIds - (Array)
    • CacheAllocatedInBytes - (Integer)
    • CacheUsedPercentage - (Numeric)
    • CacheDirtyPercentage - (Numeric)
    • CacheHitPercentage - (Numeric)
    • CacheMissPercentage - (Numeric)


# File 'lib/aws/storage_gateway/client.rb', line 181


#describe_cachedi_scsi_volumes(options = {}) ⇒ Core::Response

Calls the DescribeCachediSCSIVolumes API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_ar_ns - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • CachediSCSIVolumes - (Array)
      • VolumeARN - (String)
      • VolumeId - (String)
      • VolumeType - (String)
      • VolumeStatus - (String)
      • VolumeSizeInBytes - (Integer)
      • VolumeProgress - (Numeric)
      • SourceSnapshotId - (String)
      • VolumeiSCSIAttributes - (Hash)
        • TargetARN - (String)
        • NetworkInterfaceId - (String)
        • NetworkInterfacePort - (Integer)
        • LunNumber - (Integer)
        • ChapEnabled - (Boolean)


# File 'lib/aws/storage_gateway/client.rb', line 196


#describe_chap_credentials(options = {}) ⇒ Core::Response

Calls the DescribeChapCredentials API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :target_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • ChapCredentials - (Array)
      • TargetARN - (String)
      • SecretToAuthenticateInitiator - (String)
      • InitiatorName - (String)
      • SecretToAuthenticateTarget - (String)


# File 'lib/aws/storage_gateway/client.rb', line 218


#describe_gateway_information(options = {}) ⇒ Core::Response

Calls the DescribeGatewayInformation API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • GatewayId - (String)
    • GatewayTimezone - (String)
    • GatewayState - (String)
    • GatewayNetworkInterfaces - (Array)
      • Ipv4Address - (String)
      • MacAddress - (String)
      • Ipv6Address - (String)
    • GatewayType - (String)
    • NextUpdateAvailabilityDate - (String)


# File 'lib/aws/storage_gateway/client.rb', line 231


#describe_maintenance_start_time(options = {}) ⇒ Core::Response

Calls the DescribeMaintenanceStartTime API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • HourOfDay - (Integer)
    • MinuteOfHour - (Integer)
    • DayOfWeek - (Integer)
    • Timezone - (String)


# File 'lib/aws/storage_gateway/client.rb', line 249


#describe_snapshot_schedule(options = {}) ⇒ Core::Response

Calls the DescribeSnapshotSchedule API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)
    • StartAt - (Integer)
    • RecurrenceInHours - (Integer)
    • Description - (String)
    • Timezone - (String)


# File 'lib/aws/storage_gateway/client.rb', line 262


#describe_storedi_scsi_volumes(options = {}) ⇒ Core::Response

Calls the DescribeStorediSCSIVolumes API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_ar_ns - required - (Array)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • StorediSCSIVolumes - (Array)
      • VolumeARN - (String)
      • VolumeId - (String)
      • VolumeType - (String)
      • VolumeStatus - (String)
      • VolumeSizeInBytes - (Integer)
      • VolumeProgress - (Numeric)
      • VolumeDiskId - (String)
      • SourceSnapshotId - (String)
      • PreservedExistingData - (Boolean)
      • VolumeiSCSIAttributes - (Hash)
        • TargetARN - (String)
        • NetworkInterfaceId - (String)
        • NetworkInterfacePort - (Integer)
        • LunNumber - (Integer)
        • ChapEnabled - (Boolean)


# File 'lib/aws/storage_gateway/client.rb', line 275


#describe_upload_buffer(options = {}) ⇒ Core::Response

Calls the DescribeUploadBuffer API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • DiskIds - (Array)
    • UploadBufferUsedInBytes - (Integer)
    • UploadBufferAllocatedInBytes - (Integer)


# File 'lib/aws/storage_gateway/client.rb', line 299


#describe_working_storage(options = {}) ⇒ Core::Response

Calls the DescribeWorkingStorage API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • DiskIds - (Array)
    • WorkingStorageUsedInBytes - (Integer)
    • WorkingStorageAllocatedInBytes - (Integer)


# File 'lib/aws/storage_gateway/client.rb', line 311


#list_gateways(options = {}) ⇒ Core::Response

Calls the ListGateways API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :marker - (String)
    • :limit - (Integer)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • Gateways - (Array)
      • GatewayARN - (String)
    • Marker - (String)


# File 'lib/aws/storage_gateway/client.rb', line 323


#list_local_disks(options = {}) ⇒ Core::Response

Calls the ListLocalDisks API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • Disks - (Array)
      • DiskId - (String)
      • DiskPath - (String)
      • DiskNode - (String)
      • DiskSizeInBytes - (Integer)
      • DiskAllocationType - (String)
      • DiskAllocationResource - (String)


# File 'lib/aws/storage_gateway/client.rb', line 335


#list_volume_recovery_points(options = {}) ⇒ Core::Response

Calls the ListVolumeRecoveryPoints API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • VolumeRecoveryPointInfos - (Array)
      • VolumeARN - (String)
      • VolumeSizeInBytes - (Integer)
      • VolumeUsageInBytes - (Integer)
      • VolumeRecoveryPointTime - (String)


# File 'lib/aws/storage_gateway/client.rb', line 351


#list_volumes(options = {}) ⇒ Core::Response

Calls the ListVolumes API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :marker - (String)
    • :limit - (Integer)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)
    • Marker - (String)
    • VolumeInfos - (Array)
      • VolumeARN - (String)
      • VolumeType - (String)


# File 'lib/aws/storage_gateway/client.rb', line 365


#shutdown_gateway(options = {}) ⇒ Core::Response

Calls the ShutdownGateway API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 380


#start_gateway(options = {}) ⇒ Core::Response

Calls the StartGateway API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 389


#update_bandwidth_rate_limit(options = {}) ⇒ Core::Response

Calls the UpdateBandwidthRateLimit API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :average_upload_rate_limit_in_bits_per_sec - (Integer)
    • :average_download_rate_limit_in_bits_per_sec - (Integer)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 398


#update_chap_credentials(options = {}) ⇒ Core::Response

Calls the UpdateChapCredentials API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :target_arn - required - (String)
    • :secret_to_authenticate_initiator - required - (String)
    • :initiator_name - required - (String)
    • :secret_to_authenticate_target - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • TargetARN - (String)
    • InitiatorName - (String)


# File 'lib/aws/storage_gateway/client.rb', line 409


#update_gateway_information(options = {}) ⇒ Core::Response

Calls the UpdateGatewayInformation API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :gateway_name - (String)
    • :gateway_timezone - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 422


#update_gateway_software_now(options = {}) ⇒ Core::Response

Calls the UpdateGatewaySoftwareNow API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 433


#update_maintenance_start_time(options = {}) ⇒ Core::Response

Calls the UpdateMaintenanceStartTime API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :gateway_arn - required - (String)
    • :hour_of_day - required - (Integer)
    • :minute_of_hour - required - (Integer)
    • :day_of_week - required - (Integer)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • GatewayARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 442


#update_snapshot_schedule(options = {}) ⇒ Core::Response

Calls the UpdateSnapshotSchedule API operation.

Parameters:

  • options (Hash) (defaults to: {})
    • :volume_arn - required - (String)
    • :start_at - required - (Integer)
    • :recurrence_in_hours - required - (Integer)
    • :description - (String)

Returns:

  • (Core::Response)

    The #data method of the response object returns a hash with the following structure:

    • VolumeARN - (String)


# File 'lib/aws/storage_gateway/client.rb', line 454