-
:application_name - (String) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.
-
:version_label - (String) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.
-
:environment_ids - (Array<String>) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.
-
:environment_names - (Array<String>) If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.
-
:include_deleted - (Boolean) Indicates whether to include deleted environments: true : Environments that have been deleted after IncludedDeletedBackTo are displayed. false : Do not include deleted environments.
-
:included_deleted_back_to - (String<ISO8601 datetime>) If specified when IncludeDeleted is set to true , then environments deleted after this date are displayed.