Module: AWS::EC2::HasPermissions
Overview
Instance Method Summary collapse
-
#permissions ⇒ PermissionCollection
An object to manage the collection of permissions for this resource.
-
#private? ⇒ Object
[Boolean] True if the resource is private (i.e. not public).
-
#public=(value) ⇒ Object
Sets whether the resource is public or not.
-
#public? ⇒ Object
[Boolean] True if the resource is public.
Instance Method Details
#permissions ⇒ PermissionCollection
Returns An object to manage the collection of permissions for this resource.
38 39 40 |
# File 'lib/aws/ec2/has_permissions.rb', line 38 def PermissionCollection.new(self, :config => config) end |
#private? ⇒ Object
Returns [Boolean] True if the resource is private (i.e. not public).
27 28 29 |
# File 'lib/aws/ec2/has_permissions.rb', line 27 def private? .private? end |
#public=(value) ⇒ Object
Sets whether the resource is public or not. This has no effect on the explicit AWS account IDs that may already have permissions to use the resource.
32 33 34 |
# File 'lib/aws/ec2/has_permissions.rb', line 32 def public=(value) .public = value end |
#public? ⇒ Object
Returns [Boolean] True if the resource is public.
22 23 24 |
# File 'lib/aws/ec2/has_permissions.rb', line 22 def public? .public? end |